from typing import Callable, TypeVar
import re

import api

DEBUG_ENABLED: bool = api.config.get("DEBUG", False)

API_DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S"

ID_STRING_REGEX_NO_LENGTH = "(?=.*[a-z_-])[a-z0-9_-]*"
ID_STRING_PATTERN_NO_LENGTH = re.compile(ID_STRING_REGEX_NO_LENGTH)


print(f"Debug is enabled: {DEBUG_ENABLED}")


def _raise(exception: Exception):
    raise exception


def truncate_string(value: str, limit: int = 50) -> str:
    if len(value) <= limit:
        return value
    if limit < 5:
        raise ValueError("Truncate limit too small")  # pragma: no cover
    first = (limit-3)//2
    second = (limit-3) - first
    return value[:first] + "..." + value[(len(value)-second):len(value)]


_T = TypeVar("_T")
_R = TypeVar("_R")


def flat_map(func: Callable[[_T], list[_R]], list: list[_T]) -> list[_R]:
    res = []
    for entry in list:
        res.extend(func(entry))
    return res
