from flask import request

from api.routes import *
from api.feedback import (FEEDBACK_EMAIL_MAX_LENGTH, FEEDBACK_EMAIL_REGEX, FEEDBACK_EMAIL_PATTERN,
                          FEEDBACK_TEXT_MAX_LENGTH, FEEDBACK_MIN_PAGE_SIZE, FEEDBACK_MAX_PAGE_SIZE,
                          get_feedback_entries, put_feedback)


@api_route("/feedback/new", ["PUT"])
def api_route_feedback_new():
    json_request = get_client_json(request)
    email = json_request.get_string("email", FEEDBACK_EMAIL_MAX_LENGTH, optional=True)
    text = json_request.get_string("text", FEEDBACK_TEXT_MAX_LENGTH)
    if email is not None and not FEEDBACK_EMAIL_PATTERN.fullmatch(email):
        raise json_request.get("email").raise_error(f"Does not match pattern {FEEDBACK_EMAIL_REGEX}")
    
    put_feedback(email, text)
    return {}, HTTP_201_CREATED


@api_route("/feedback", ["GET"], allow_while_readonly=True)
@api_moderator_route()
def api_route_feedback():
    entries_per_page = api_request_get_query_int("entries_per_page", 50, FEEDBACK_MIN_PAGE_SIZE, FEEDBACK_MAX_PAGE_SIZE)
    page = api_request_get_query_int("page", 0)
    
    page_count, page = get_feedback_entries(entries_per_page, page)
    return {
        "page_count": page_count,
        "page": page
    }
